# Generated by Django 5.0.6 on 2025-04-04 14:56

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_location", "0003_region_code"),
    ]

    operations = [
        migrations.CreateModel(
            name="Currency",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        help_text="Created at",
                        verbose_name="Created at",
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        auto_now=True, help_text="Updated at", verbose_name="Updated at"
                    ),
                ),
                (
                    "status",
                    models.BooleanField(
                        default=True, help_text="Status", verbose_name="Status"
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        help_text="Currency name",
                        max_length=100,
                        verbose_name="Currency name",
                    ),
                ),
                (
                    "code",
                    models.CharField(
                        help_text="Currency code",
                        max_length=10,
                        verbose_name="Currency code",
                    ),
                ),
                (
                    "simbol",
                    models.CharField(
                        help_text="Currency symbol",
                        max_length=10,
                        verbose_name="Currency symbol",
                    ),
                ),
                (
                    "description",
                    models.CharField(
                        help_text="Currency description",
                        max_length=100,
                        verbose_name="Currency description",
                    ),
                ),
                (
                    "country",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="+",
                        to="artd_location.country",
                    ),
                ),
            ],
            options={
                "verbose_name": "Currency",
                "verbose_name_plural": "Currencies",
            },
        ),
    ]



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _
from django.conf import settings


class ArtdLocationConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "artd_location"
    verbose_name = _("Location")

    def ready(self) -> None:
        from artd_location import signals  # noqa: F401



# Generated by Django 5.0.6 on 2025-04-04 14:58

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("artd_location", "0004_currency"),
    ]

    operations = [
        migrations.RenameField(
            model_name="currency",
            old_name="simbol",
            new_name="symbol",
        ),
    ]



from django.utils.translation import gettext_lazy as _

CURRENCIES = [
    {
        "name": _("Peso Argentino"),
        "code": "ARS",
        "symbol": "$",
        "country": 12,
    },
    {
        "name": _("Boliviano"),
        "code": "BOB",
        "symbol": "Bs.",
        "country": 28,
    },
    {
        "name": _("Real Brasileño"),
        "code": "BRL",
        "symbol": "R$",
        "country": 31,
    },
    {
        "name": _("Peso Chileno"),
        "code": "CLP",
        "symbol": "$",
        "country": 41,
    },
    {
        "name": _("Peso Colombiano"),
        "code": "COP",
        "symbol": "$",
        "country": 45,
    },
    {
        "name": _("Colón Costarricense"),
        "code": "CRC",
        "symbol": "₡",
        "country": 52,
    },
    {
        "name": _("Peso Cubano"),
        "code": "CUP",
        "symbol": "$",
        "country": 54,
    },
    {
        "name": _("Dólar Estadounidense"),
        "code": "USD",
        "symbol": "$",
        "country": 57,
    },
    {
        "name": _("Quetzal"),
        "code": "GTQ",
        "symbol": "Q",
        "country": 82,
    },
    {
        "name": _("Lempira"),
        "code": "HNL",
        "symbol": "L",
        "country": 90,
    },
    {
        "name": _("Peso Mexicano"),
        "code": "MXN",
        "symbol": "$",
        "country": 141,
    },
    {
        "name": _("Córdoba Nicaragüense"),
        "code": "NIO",
        "symbol": "C$",
        "country": 164,
    },
    {
        "name": _("Balboa"),
        "code": "PAB",
        "symbol": "B/.",
        "country": 176,
    },
    {
        "name": _("Guaraní"),
        "code": "PYG",
        "symbol": "₲",
        "country": 178,
    },
    {
        "name": _("Sol Peruano"),
        "code": "PEN",
        "symbol": "S/",
        "country": 179,
    },
    {
        "name": _("Peso Dominicano"),
        "code": "DOP",
        "symbol": "RD$",
        "country": 188,
    },
    {
        "name": _("Peso Uruguayo"),
        "code": "UYU",
        "symbol": "$",
        "country": 237,
    },
    {
        "name": _("Bolívar"),
        "code": "VES",
        "symbol": "Bs.",
        "country": 240,
    },
]



# Generated by Django 5.0.6 on 2025-04-02 20:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_location", "0002_alter_city_created_at_alter_city_status_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="region",
            name="code",
            field=models.CharField(
                blank=True,
                help_text="Region code",
                max_length=10,
                null=True,
                verbose_name="Region code",
            ),
        ),
    ]



"""
* Copyright (C) ArtD SAS - All Rights Reserved
* Unauthorized copying of this file, via any medium is strictly prohibited
* Proprietary and confidential
* Written by Jonathan Favian Urzola Maldonado <jonathan@artd.com.co>, 2023
"""

from django.contrib import admin

from artd_location.models import City, Country, Region, Currency
from django.utils.translation import gettext_lazy as _


@admin.register(Country)
class CountryAdmin(admin.ModelAdmin):
    search_fields = [
        "spanish_name",
        "english_name",
        "nom",
        "iso2",
        "iso3",
        "phone_code",
        "id",
    ]
    list_display = [
        "spanish_name",
        "id",
        "english_name",
        "nom",
        "iso2",
        "iso3",
        "phone_code",
        "status",
    ]
    readonly_fields = [
        "spanish_name",
        "english_name",
        "nom",
        "iso2",
        "iso3",
        "phone_code",
        "status",
        "created_at",
        "updated_at",
    ]
    fieldsets = (
        (
            None,
            {
                "fields": (
                    "spanish_name",
                    "english_name",
                    "nom",
                    "status",
                )
            },
        ),
        (
            _("ISO codes"),
            {
                "fields": (
                    "iso2",
                    "iso3",
                ),
            },
        ),
        (
            _("Phone code"),
            {
                "fields": ("phone_code",),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                ),
            },
        ),
    )

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False

    def has_add_permission(self, request, obj=None):
        return False


@admin.register(Region)
class RegionAdmin(admin.ModelAdmin):
    search_fields = [
        "name",
        "id",
        "country__spanish_name",
        "country__english_name",
    ]
    list_display = [
        "name",
        "id",
        "country",
        "status",
    ]

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False

    def has_add_permission(self, request, obj=None):
        return False


@admin.register(City)
class CityAdmin(admin.ModelAdmin):
    search_fields = [
        "name",
        "name_in_capital_letters",
        "code",
        "region__name",
        "id",
    ]
    list_display = [
        "name",
        "id",
        "name_in_capital_letters",
        "region",
        "code",
        "status",
    ]

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False

    def has_add_permission(self, request, obj=None):
        return False


@admin.register(Currency)
class CurrencyAdmin(admin.ModelAdmin):
    search_fields = [
        "name",
        "code",
        "id",
    ]
    list_display = [
        "name",
        "id",
        "code",
        "symbol",
        "country",
        "status",
    ]

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False

    def has_add_permission(self, request, obj=None):
        return False



import json
from django.core.management.base import BaseCommand
from artd_location.models import Currency, Country
from artd_location.data.currencies import CURRENCIES


class Command(BaseCommand):
    help = "Populates the database with Latin American currencies"

    def handle(self, *args, **kwargs):
        try:
            for currency_data in CURRENCIES:
                country = Country.objects.get(id=currency_data["country"])
                if not country:
                    self.stderr.write(
                        self.style.ERROR(
                            f"Country with ID {currency_data['country']} does not exist."
                        )
                    )
                    continue
                Currency.objects.update_or_create(
                    code=currency_data["code"],
                    defaults={
                        "name": currency_data["name"],
                        "symbol": currency_data["symbol"],
                        "country": country,
                    },
                )

            self.stdout.write(
                self.style.SUCCESS("Currencies have been successfully added.")
            )
        except FileNotFoundError:
            self.stderr.write(
                self.style.ERROR("The file 'currencies.json' was not found.")
            )
        except Exception as e:
            self.stderr.write(self.style.ERROR(f"An error occurred: {str(e)}"))



from django.core.management.base import BaseCommand

from artd_location.data.chile_cities import CITIES
from artd_location.models import City, Region


class Command(BaseCommand):
    help = "Create cities in Chile"

    def handle(self, *args, **kwargs):
        for city in CITIES:
            region = Region.objects.get(id=city[1])
            name: str = city[3]
            name = name.title()
            name_in_capital_letters: str = city[4]
            name_in_capital_letters = name_in_capital_letters.upper()
            if City.objects.filter(id=city[0]).count() == 0:
                City.objects.create(
                    id=city[0],
                    name=name,
                    name_in_capital_letters=name_in_capital_letters,
                    code=city[2],
                    region=region,
                )
                self.stdout.write(self.style.SUCCESS(f"{city[3]} was created"))
            else:
                city_obj = City.objects.get(
                    id=city[0],
                )
                city_obj.name = name
                city_obj.name_in_capital_letters = name_in_capital_letters
                city_obj.code = city[2]
                city_obj.region = region
                city_obj.save()
                self.stdout.write(self.style.WARNING(f"{city[3]} was updated"))
